@@ -1,17 +1,17 @@
 require 'rbconfig'
-require 'tempfile'
+
+require "vagrant/util/subprocess"
 
 module Vagrant
   module Util
     # This class just contains some platform checking code.
     class Platform
       class << self
-        def tiger?
-          platform.include?("darwin8")
-        end
+        def cygwin?
+          return true if ENV["VAGRANT_DETECTED_OS"] &&
+            ENV["VAGRANT_DETECTED_OS"].downcase.include?("cygwin")
 
-        def leopard?
-          platform.include?("darwin9")
+          platform.include?("cygwin")
         end
 
         [:darwin, :bsd, :freebsd, :linux, :solaris].each do |type|
@@ -28,37 +28,27 @@ module Vagrant
           false
         end
 
-        # Returns boolean noting whether this is a 64-bit CPU. This
-        # is not 100% accurate and there could easily be false negatives.
+        # This takes any path and converts it to a full-length Windows
+        # path on Windows machines in Cygwin.
         #
-        # @return [Boolean]
-        def bit64?
-          ["x86_64", "amd64"].include?(RbConfig::CONFIG["host_cpu"])
-        end
+        # @return [String]
+        def cygwin_windows_path(path)
+          return path if !cygwin?
 
-        # Returns boolean noting whether this is a 32-bit CPU. This
-        # can easily throw false positives since it relies on {#bit64?}.
-        #
-        # @return [Boolean]
-        def bit32?
-          !bit64?
+          process = Subprocess.execute("cygpath", "-w", "-l", "-a", path.to_s)
+          process.stdout.chomp
         end
 
         # Returns a boolean noting whether the terminal supports color.
         # output.
         def terminal_supports_colors?
           if windows?
-            return ENV.has_key?("ANSICON")
+            return ENV.has_key?("ANSICON") || cygwin?
           end
 
           true
         end
 
-        def tar_file_options
-          # create, write only, fail if the file exists, binary if windows
-          File::WRONLY | File::EXCL | File::CREAT | (windows? ? File::BINARY : 0)
-        end
-
         def platform
           RbConfig::CONFIG["host_os"].downcase
         end
